@@ -580,15 +580,15 @@ class PasswordExpiredDialog(mforms.Form):
         vbox.add(hbox, False, True)
 
         self.old_password = mforms.newTextEntry(mforms.PasswordEntry)
-        box.add(newLabel("Old Password:", True), 0, 1, 0, 1, mforms.HFillFlag)
+        box.add(newLabel("Old Password:", True), 0, 1, 0, 1, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.old_password, 1, 2, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
 
         self.password = mforms.newTextEntry(mforms.PasswordEntry)
-        box.add(newLabel("New Password:", True), 0, 1, 1, 2, mforms.HFillFlag)
+        box.add(newLabel("New Password:", True), 0, 1, 1, 2, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.password, 1, 2, 1, 2, mforms.HFillFlag|mforms.HExpandFlag)
 
         self.confirm = mforms.newTextEntry(mforms.PasswordEntry)
-        box.add(newLabel("Confirm:", True), 0, 1, 2, 3, mforms.HFillFlag)
+        box.add(newLabel("Confirm:", True), 0, 1, 2, 3, mforms.HFillFlag|mforms.VFillFlag)
         box.add(self.confirm, 1, 2, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
 
         bbox = newBox(True)
@@ -604,7 +604,7 @@ class PasswordExpiredDialog(mforms.Form):
 
         self.set_content(vbox)
 
-        self.set_size(500, 260)
+        self.set_size(500, 300)
         self.center()
 
 
